# -*- coding: utf-8; -*-
################################################################################
#
#  WuttaPOS -- Pythonic Point of Sale System
#  Copyright © 2023 Lance Edgar
#
#  This file is part of WuttaPOS.
#
#  WuttaPOS is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  WuttaPOS is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  WuttaPOS.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
WuttaPOS - header control
"""

import flet as ft

from .base import WuttaControl
from .timestamp import WuttaTimestamp


class WuttaHeader(WuttaControl):

    def build(self):
        self.txn_display = ft.Text("Txn: N", weight=ft.FontWeight.BOLD, size=20)
        self.cust_display = ft.Text("Cust: N", weight=ft.FontWeight.BOLD, size=20)
        self.user_display = ft.Text("User: N", weight=ft.FontWeight.BOLD, size=20)
        self.logout_button = ft.FilledButton("Logout", on_click=self.logout_click, visible=False)
        self.logout_divider = ft.VerticalDivider(visible=False)

        controls = [
            self.txn_display,
            ft.VerticalDivider(),
            self.cust_display,
            ft.VerticalDivider(),
            WuttaTimestamp(self.config, expand=True,
                           weight=ft.FontWeight.BOLD, size=20),
            self.user_display,
            ft.VerticalDivider(),
            self.logout_button,
            self.logout_divider,
            ft.Text(f"WuttaPOS", weight=ft.FontWeight.BOLD, size=20),
        ]

        return ft.Row(controls)

    def did_mount(self):
        self.informed_refresh()

    def informed_refresh(self):
        self.update_txn_display()
        self.update_cust_display()
        self.update_user_display()
        self.update()

    def update_txn_display(self):
        txn_display = None
        if self.page:
            txn_display = self.page.session.get('txn_display')
        self.txn_display.value = f"Txn: {txn_display or 'N'}"

    def update_cust_display(self):
        cust_display = None
        if self.page:
            cust_display = self.page.session.get('cust_display')
        self.cust_display.value = f"Cust: {cust_display or 'N'}"

    def update_user_display(self):
        user_display = None
        if self.page:
            user_display = self.page.session.get('user_display')
        self.user_display.value = f"User: {user_display or 'N'}"

        if self.page and self.page.session.get('user_uuid'):
            self.logout_button.visible = True
            self.logout_divider.visible = True

    def logout_click(self, e):

        # TODO: hacky but works for now
        if not self.config.production():
            self.page.client_storage.set('user_uuid', '')

        self.page.session.clear()
        self.page.go('/login')
